@@ -2,7 +2,7 @@ package Shipwright;
 
 use warnings;
 use strict;
-use version; our $VERSION = qv('2.4.13');
+use version; our $VERSION = qv('2.4.14');
 
 use base qw/Class::Accessor::Fast/;
 
@@ -27,6 +27,10 @@ unless ( defined $ENV{FTP_PASSIVE} ) {
     $ENV{FTP_PASSIVE} = 1;
 }
 
+=head2 new
+
+=cut
+
 sub new {
     my $class = shift;
 
@@ -73,40 +77,29 @@ Shipwright - Best Practical Builder
 
 =head1 SYNOPSIS
 
-    use Shipwright;
+    $ export SHIPWRIGHT_SHIPYARD=fs:/tmp/fs
+    $ shipwright create 
+    # import will take a while, enjoy your coffee!
+    $ shipwright import cpan:Jifty
+    $ cd /tmp/fs
+    $ ./bin/shipwright-builder --install-base /tmp/jifty
+
+    one liner doing the same thing:
+    $ shipwright-generate cpan:Jifty | perl - --install-base /tmp/jifty
+
 
 =head1 DESCRIPTION
 
 =head2 Why use Shipwright?
 
-Shipwright is a tool to help you bundle your software.
-
 Most software packages depend on other bits of software in order to avoid code
-repetition and repeating work that's already been done. This can result in pain
-and suffering when attempting to install the software, due to having to
-untangle the maze of dependencies. First, non-CPAN dependencies must be found
-and installed. Then, CPAN:: or CPANPLUS:: can be used to install all
-dependencies available on CPAN with minimal pain.
+repetition. This may result in pain when attempting to install the software,
+due to the maze of dependencies, especially for large projects with many
+dependencies.
 
-While this works, it has some drawbacks, especially for large projects which
-have many dependencies. Installation can take many iterations of trying to
-install from CPAN and then stopping to install other non-CPAN dependencies that
-the CPAN packages depend on. For example, SVK requires the non-CPAN packages
-subversion and swig. In the end, installing large projects with many
-dependencies is not very friendly for users, especially since dependencies may
-change their functionality and break builds with untested versions.
-
-Enter Shipwright, a tool to help you bundle your software with all of its
+Shipwright is a tool to help you bundle your software with all its
 dependencies, regardless of whether they are CPAN modules or non-Perl modules
-from elsewhere. Shipwright makes it easy to build and install a bundle of your
-software, usually with just a single command:
-
-$ ./bin/shipwright-builder
-
-As a general note when reading this and other Shipwright documentation: we
-will often call a piece of software that your software depends on and is
-distributed elsewhere a I<dist>, short for distribution. This and other
-Shipwright terminology are defined in L<Shipwright::Manual::Glossary>.
+from elsewhere. Shipwright makes the bundle work easy.
 
 =head2 Introduction
 
@@ -117,10 +110,10 @@ probably a better place to start.
 
 The idea of Shipwright is simple:
 
-   raw material                   shipwright factory
+    sources                        shipwright factory
 ---------------------           ------------------------
-|  all the separate |  import   |  internal shipwright |  build
-|  dist sources     |  =====>   |  repository          |  ====>
+|  all the separate |  import   |  shipyard             |  build
+|  sources          |  =====>   |                       |  ====>
 ---------------------           ------------------------
 
      vessel (final product)
@@ -128,58 +121,61 @@ The idea of Shipwright is simple:
 | all packages installed with smart wrappers |
 ----------------------------------------------
 
-There are two main commands in shipwright: import and build, which can be
-invoked like this:
+=head2 What's in a shipyard
 
-$ shipwright import ...
+=head3 shipyard after initialization
 
-$ check out your repository and cd there
-$ ./shipwright-builder ...
-
-=head2 What's in a Shipwright repository or vessel
-
-=head3 repository after initialization
-
-After initializing a project, the files in the repository are:
+After initializing a shipyard, the files in the repository are:
 
 bin/
-     # used for building, installing and testing
+    # used for building, installing and testing
      shipwright-builder
-
     # a utility for doing things such as updating the build order
      shipwright-utility
 
 etc/
     # wrapper for installed bin files, mainly for optimizing the environment
      shipwright-script-wrapper
-
     # wrapper for installed perl scripts
     shipwright-perl-wrapper
-
     # source files you can `source', for tcsh and bash, respectively.
     # both will be installed to tools/
     shipwright-source-tcsh, shipwright-source-bash
-
     # utility which will be installed to tools/
     shipwright-utility
+    # set env bat for windows
+    shipwright-windows-setenv.bat
 
-sources/      # all the sources of your dists live here
+inc/ # modules for shipwright itself
+
+sources/      # all the sources live here
 
 scripts/    # all the build scripts and dependency hints live here
 
 shipwright/
-    # the actual build order
-    order.yml
-    # non-cpan dists' name => url map
-    source.yml
+
+    # branches note, see L<Shipwright::Manual::UsingBranches>
+    branches.yml
+    # flags note, see L<Shipwright::Manual::UsingFlags>
+    flags.yml		
+    # test failures note
+    known_test_failures.yml
     # cpan dists' module => name map
     map.yml
+    # the actual build order
+    order.yml
+    # reference count note
+    refs.yml
+    # non-cpan dists' name => url map
+    source.yml
+    # sources' version
+    version.yml
 
 t/
     # will run this if with --only-test when build
     test
 
-=head3 repository after import
+=head3 shipyard after import
 
 After importing, say cpan:Acme::Hello, both the sources and scripts directories
 will have a `cpan-Acme-Hello' directory.
@@ -188,11 +184,11 @@ Under scripts/cpan-Acme-Hello there are two files: 'build' and 'require.yml'.
 
 =head4 build
 
-configure: %%PERL%% Build.PL --install_base=%%INSTALL_BASE%%
-make: %%PERL%% Build
-test: %%PERL%% Build test
-install: %%PERL%% Build install
-clean: %%PERL%% Build realclean
+configure: %%PERL%% %%MODULE_BUILD_BEFORE_BUILD_PL%% Build.PL --install_base=%%INSTALL_BASE%% --install_path lib=%%INSTALL_BASE%%/lib/perl5 --install_path arch=%%INSTALL_BASE%%/lib/perl5
+make: %%PERL%% %%MODULE_BUILD_BEFORE_BUILD%% Build
+test: %%PERL%% %%MODULE_BUILD_BEFORE_BUILD%% Build test
+install: %%PERL%% %%MODULE_BUILD_BEFORE_BUILD%% Build install
+clean: %%PERL%% %%MODULE_BUILD_BEFORE_BUILD%% Build realclean
 
 Each line is of `type: command' format, and the command is executed line by
 line (which is also true for t/test).
@@ -216,54 +212,8 @@ right build order.
 
 =head4 vessel
 
-After the source repository is built, we have a new directory structure
-which we call a I<vessel>.
-
-Normally, the vessel contains bin/, bin-wrapper/, etc/, tools/ and lib/
-directories. One thing to note is that files below bin/ are for you to run,
-while the files below bin-wrapper/ are not. The bin/ directory contains links
-to a wrapper around the files in bin-wrapped/, and these programs will only
-work correctly if run through the wrapper.
-
-=head2 METHODS
-
-=head3 new PARAMHASH
-
-This class method instantiates a new Shipwright object, which initializes
-all Shipwright components (if possible).
-
-=head4 Arguments
-
-general part:
-
-    repository: specify backend's path, e.g. svk:/t/test
-    log_level: specify log level, default is FATAL
-    log_file: specify log file, default is append to screen
-
-source part:
-
-    source: the source we need to import
-    name: source's name
-    follow: follow dependency chain or not, default is true
-    min_perl_version: minimal required perl version,
-             default is the same as the perl which is running shipwright
-    skip: hashref where the keys are the skipped modules when importing,
-          default is undefined
-    version: source's version, default is undefined
-
-build part:
-
-    perl: the path of the perl that runs the commands in scripts/foo/build(.pl),
-          default is $^X, the one that is running shipwright
-    skip: hashref where the keys are the skipped dists when install,
-          default is undefined
-    skip_test: skip test or not, default is false
-    install_base: install base path, default is a temp directory
-    force: force install even if tests fail, default is false
-    only_test: don't install, just test, (used for previously installed dists),
-                default is false
-    flags: flags for building, default is { default => 1 }
-    branches: branches build should use
+After the cmd `./bin/shipwright-builder --install-base /tmp/vessel`,
+we have a new directory structure which we call a I<vessel>(/tmp/vessel).
 
 =head1 SEE ALSO
 
